pub type DeferredDispatch<T: Config> = StorageMap<_GeneratedPrefixForStorageDeferredDispatch<T>, Twox64Concat, T::Hash, ProvidedBlockNumberFor<T>, OptionQuery>;Expand description
Deferred dispatches, mapping a call hash to the provided block number at which the deferral expires and the entry can be permissionlessly removed.
Storage type is [StorageMap] with key type T :: Hash and value type ProvidedBlockNumberFor < T >.
Aliased Type
pub struct DeferredDispatch<T: Config>(/* private fields */);